Index: applications/editors/josm/plugins/cadastre-fr/src/cadastre_fr/CadastreGrabber.java
===================================================================
--- applications/editors/josm/plugins/cadastre-fr/src/cadastre_fr/CadastreGrabber.java	(revision 18962)
+++ applications/editors/josm/plugins/cadastre-fr/src/cadastre_fr/CadastreGrabber.java	(revision 19078)
@@ -46,5 +46,5 @@
     private URL getURLRaster(WMSLayer wmsLayer, EastNorth lambertMin, EastNorth lambertMax) throws MalformedURLException {
         // GET /scpc/wms?version=1.1&request=GetMap&layers=CDIF:PMC@QH4480001701&format=image/png&bbox=-1186,0,13555,8830&width=576&height=345&exception=application/vnd.ogc.se_inimage&styles= HTTP/1.1
-        final int cRasterX = 1000; // keep width constant and adjust width to original image proportions
+        final int cRasterX = 800; // keep width constant and adjust width to original image proportions
         String str = new String(wmsInterface.baseURL+"/scpc/wms?version=1.1&request=GetMap");
         str += "&layers=CDIF:PMC@";
@@ -73,6 +73,6 @@
         str += lambertMax.east() + ",";
         str += lambertMax.north();
-        //str += "&width=800&height=600"; // maximum allowed by wms server
-        str += "&width=1000&height=800"; // maximum allowed by wms server
+        str += "&width=800&height=600"; // maximum allowed by wms server
+        //str += "&width=1000&height=800"; // maximum allowed by wms server
         //str += "&exception=application/vnd.ogc.se_inimage"; // used by normal client but not required
         str += "&styles=LS3_90,LS2_90,LS1_90,PARCELLE_90,NUMERO_90,PT3_90,PT2_90,PT1_90,LIEUDIT_90";
Index: applications/editors/josm/plugins/cadastre-fr/src/cadastre_fr/CadastreInterface.java
===================================================================
--- applications/editors/josm/plugins/cadastre-fr/src/cadastre_fr/CadastreInterface.java	(revision 18962)
+++ applications/editors/josm/plugins/cadastre-fr/src/cadastre_fr/CadastreInterface.java	(revision 19078)
@@ -92,5 +92,5 @@
         try {
             // first, get the cookie from Cadastre to allow next downloads
-            searchFormURL = new URL(baseURL + "/scpc/rechercherPlan.do");
+            searchFormURL = new URL(baseURL + "/scpc/accueil.do");
             urlConn = (HttpURLConnection)searchFormURL.openConnection();
             urlConn.setRequestMethod("GET");
@@ -231,4 +231,6 @@
             content += "&codeDepartement=";
             content += "&nbResultatParPage=10";
+            content += "&x=0&y=0";
+            searchFormURL = new URL(baseURL + "/scpc/rechercherPlan.do");
             urlConn = (HttpURLConnection)searchFormURL.openConnection();
             urlConn.setRequestMethod("POST");
Index: applications/editors/josm/plugins/cadastre-fr/src/cadastre_fr/CadastrePlugin.java
===================================================================
--- applications/editors/josm/plugins/cadastre-fr/src/cadastre_fr/CadastrePlugin.java	(revision 18962)
+++ applications/editors/josm/plugins/cadastre-fr/src/cadastre_fr/CadastrePlugin.java	(revision 19078)
@@ -87,7 +87,8 @@
  *                 - removed autosourcing of empty new nodes
  * 1.6 28-Nov-2009 - Fix minor issues if Grab is called without layer (possible since projection rework)
+ * 1.7 12-Dec-2009 - Change URL's changes for cookie and downgrade imgs resolution due to WMS changes 
  */
 public class CadastrePlugin extends Plugin {
-    static String VERSION = "1.6";
+    static String VERSION = "1.7";
 
     static JMenu cadastreJMenu;
Index: applications/editors/josm/plugins/cadastre-fr/src/cadastre_fr/SimplifyWay.java
===================================================================
--- applications/editors/josm/plugins/cadastre-fr/src/cadastre_fr/SimplifyWay.java	(revision 18962)
+++ applications/editors/josm/plugins/cadastre-fr/src/cadastre_fr/SimplifyWay.java	(revision 19078)
@@ -9,5 +9,4 @@
 import java.util.LinkedList;
 import java.util.List;
-import java.util.Set;
 
 import org.openstreetmap.josm.Main;

Index: applications/editors/josm/plugins/cadastre-fr/src/cadastre_fr/CadastrePreferenceSetting.java
===================================================================
--- applications/editors/josm/plugins/cadastre-fr/src/cadastre_fr/CadastrePreferenceSetting.java	(revision 18962)
+++ applications/editors/josm/plugins/cadastre-fr/src/cadastre_fr/CadastrePreferenceSetting.java	(revision 19078)
@@ -172,9 +172,9 @@
         cadastrewms.add(new JSeparator(SwingConstants.HORIZONTAL), GBC.eol().fill(GBC.HORIZONTAL));
 
         // for raster images (not vectorized), image grab divider (from 1 to 10)
         String savedRasterDivider = Main.pref.get("cadastrewms.rasterDivider", DEFAULT_RASTER_DIVIDER);
         JLabel jLabelRasterDivider = new JLabel(tr("Raster images grab multiplier:"));
         rasterDivider.setText(savedRasterDivider);
-        rasterDivider.setToolTipText("Raster image grab division, from 1 to 10; 10 is very high definition");
+        rasterDivider.setToolTipText("Raster image grab division, from 1 to 12; 12 is very high definition");
         cadastrewms.add(jLabelRasterDivider, GBC.std().insets(0, 5, 10, 0));
         cadastrewms.add(rasterDivider, GBC.eol().fill(GBC.HORIZONTAL).insets(5, 5, 200, 5));
@@ -248,5 +248,5 @@
         try {
             int i = Integer.parseInt(rasterDivider.getText());
-            if (i > 0 && i < 11)
+            if (i > 0 && i < 13)
                 Main.pref.put("cadastrewms.rasterDivider", String.valueOf(i));
         } catch (NumberFormatException e) { // ignore the last input
@@ -172,9 +172,9 @@
         cadastrewms.add(new JSeparator(SwingConstants.HORIZONTAL), GBC.eol().fill(GBC.HORIZONTAL));
 
-        // for raster images (not vectorized), image grab divider (from 1 to 10)
+        // for raster images (not vectorized), image grab divider (from 1 to 12)
         String savedRasterDivider = Main.pref.get("cadastrewms.rasterDivider", DEFAULT_RASTER_DIVIDER);
         JLabel jLabelRasterDivider = new JLabel(tr("Raster images grab multiplier:"));